@@ -34,7 +34,7 @@ av_meta_reader_class_init (AVMetaReaderClass *klass)
 G_DEFINE_TYPE (AVMetaReader, av_meta_reader, G_TYPE_OBJECT)
 
 gboolean av_meta_reader_read (AVMetaReader *reader,
-			      DAAPRecord *record,
+			      DmapAvRecord *record,
 			      const gchar *path)
 {
 	return AV_META_READER_GET_CLASS (reader)->read (reader, record, path);
