@@ -31,16 +31,16 @@ struct AVRenderGstPrivate {
 	
 	gchar      *host;
 	guint       port;
-	DMAPMdnsBrowserTransportProtocol transport_protocol;
+	DmapMdnsServiceTransportProtocol transport_protocol;
 
 	GstElement *pipeline;
 	GstElement *src_decoder;
 	GstElement *resample;
 	GstElement *sink;
 
-	gboolean	shuffle_state;
-	DACPRepeatState repeat_state;
-	DACPPlayState   play_state;
+	gboolean	       shuffle_state;
+	DmapControlRepeatState repeat_state;
+	DmapControlPlayState   play_state;
 
 	GList *song_list;	// Songs to play.
 	GList *song_current;	// Song currently playing.
@@ -58,23 +58,23 @@ enum {
 	PROP_TRANSPORT_PROTOCOL
 };
 
-DAAPRecord *
-av_render_gst_now_playing_record (DACPPlayer * player)
+DmapAvRecord *
+av_render_gst_now_playing_record (DmapControlPlayer * player)
 {
-	DAAPRecord *fnval;
+	DmapAvRecord *fnval;
 	AVRenderGst *render = AV_RENDER_GST (player);
 
 	if (render->priv->song_current == NULL) {
 		fnval = NULL;
 	} else {
-		fnval = DAAP_RECORD (render->priv->song_current->data);
+		fnval = DMAP_AV_RECORD (render->priv->song_current->data);
 	}
 
 	return fnval;
 }
 
 guchar *
-av_render_gst_now_playing_artwork (DACPPlayer * player, guint width,
+av_render_gst_now_playing_artwork (DmapControlPlayer * player, guint width,
 				 guint height)
 {
 	g_warning ("Now playing artwork not implemented");
@@ -82,14 +82,14 @@ av_render_gst_now_playing_artwork (DACPPlayer * player, guint width,
 }
 
 void
-av_render_gst_pause (DACPPlayer * player)
+av_render_gst_pause (DmapControlPlayer * player)
 {
 	transition_pipeline (AV_RENDER_GST (player)->priv->pipeline, GST_STATE_PAUSED, TRANSITION_TIMEOUT);
-	AV_RENDER_GST (player)->priv->play_state = DACP_PLAY_PAUSED;
+	AV_RENDER_GST (player)->priv->play_state = CONTROL_PLAY_PAUSED;
 }
 
 void
-av_render_gst_play_pause (DACPPlayer * player)
+av_render_gst_play_pause (DmapControlPlayer * player)
 {
 	AVRenderGst *render = AV_RENDER_GST (player);
 
@@ -99,7 +99,7 @@ av_render_gst_play_pause (DACPPlayer * player)
 		if (ret == GST_STATE_CHANGE_SUCCESS) {
 			if (state == GST_STATE_PAUSED) {
 				transition_pipeline (render->priv->pipeline, GST_STATE_PLAYING, TRANSITION_TIMEOUT);
-				render->priv->play_state = DACP_PLAY_PLAYING;
+				render->priv->play_state = CONTROL_PLAY_PLAYING;
 			} else {
 				av_render_gst_pause (player);
 			}
@@ -110,10 +110,10 @@ av_render_gst_play_pause (DACPPlayer * player)
 // FIXME EOS handler goes to next song; should this be more explicit here?
 void play_list_starting_at_current (AVRenderGst *render)
 {
-	gchar *location;
+	gchar *location = NULL;
 
 	transition_pipeline (render->priv->pipeline, GST_STATE_READY, TRANSITION_TIMEOUT);
-	render->priv->play_state = DACP_PLAY_STOPPED;
+	render->priv->play_state = CONTROL_PLAY_STOPPED;
 
 	g_object_get (render->priv->song_current->data, "location", &location, NULL);
 	g_object_set (G_OBJECT (render->priv->src_decoder), "uri", location, NULL);
@@ -121,11 +121,13 @@ void play_list_starting_at_current (AVRenderGst *render)
 	g_debug ("Playing %s", location);
 
 	transition_pipeline (render->priv->pipeline, GST_STATE_PLAYING, TRANSITION_TIMEOUT);
-	render->priv->play_state = DACP_PLAY_PLAYING;
+	render->priv->play_state = CONTROL_PLAY_PLAYING;
+
+	g_free(location);
 }
 
 void
-av_render_gst_next_item (DACPPlayer * player)
+av_render_gst_next_item (DmapControlPlayer * player)
 {
 	AVRenderGst *render = AV_RENDER_GST (player);
 
@@ -134,7 +136,7 @@ av_render_gst_next_item (DACPPlayer * player)
 }
 
 void
-av_render_gst_prev_item (DACPPlayer * player)
+av_render_gst_prev_item (DmapControlPlayer * player)
 {
 	g_warning ("Previous item not implemented");
 }
@@ -148,7 +150,7 @@ static void av_render_gst_reset (AVRenderGst *render)
 }
 
 void
-av_render_gst_cue_clear (DACPPlayer * player)
+av_render_gst_cue_clear (DmapControlPlayer * player)
 {
 	AVRenderGst *render = AV_RENDER_GST (player);
 
@@ -162,7 +164,7 @@ av_render_gst_cue_clear (DACPPlayer * player)
 	if (render->priv->pipeline) {
 		g_idle_add ((GSourceFunc) g_main_loop_quit, render->priv->loop);
 		transition_pipeline (render->priv->pipeline, GST_STATE_NULL, TRANSITION_TIMEOUT);
-		render->priv->play_state = DACP_PLAY_STOPPED;
+		render->priv->play_state = CONTROL_PLAY_STOPPED;
 		gst_object_unref (render->priv->pipeline);
 		av_render_gst_reset (render);
 	}
@@ -213,13 +215,13 @@ gboolean bus_cb (GstBus *bus, GstMessage *message, AVRenderGst *render)
 	case GST_MESSAGE_ERROR:
 		g_warning ("GStreamer error message");
 		transition_pipeline (render->priv->pipeline, GST_STATE_READY, TRANSITION_TIMEOUT);
-		render->priv->play_state = DACP_PLAY_STOPPED;
+		render->priv->play_state = CONTROL_PLAY_STOPPED;
 		g_idle_add ((GSourceFunc) g_main_loop_quit, render->priv->loop);
 		break;
 	case GST_MESSAGE_EOS:
 		g_debug ("GStreamer EOS message");
 		if (render->priv->song_current && render->priv->song_current->next) {
-			av_render_gst_next_item (DACP_PLAYER (render));
+			av_render_gst_next_item (DMAP_CONTROL_PLAYER (render));
 		} else {
 			g_idle_add ((GSourceFunc) g_main_loop_quit, render->priv->loop);
 		}
@@ -281,12 +283,14 @@ _error:
 		g_object_unref (convert);
 	if (sink != NULL)
 		g_object_unref (sink);
+	if (pipeline != NULL)
+		g_object_unref (pipeline);
 
 	return NULL;
 }
 
 void
-av_render_gst_cue_play (DACPPlayer * player, GList * records, guint index)
+av_render_gst_cue_play (DmapControlPlayer * player, GList * records, guint index)
 {
 	AVRenderGst *render = AV_RENDER_GST (player);
 
@@ -331,7 +335,7 @@ av_render_gst_cue_play (DACPPlayer * player, GList * records, guint index)
 
 	if (transition_pipeline (render->priv->pipeline, GST_STATE_NULL, TRANSITION_TIMEOUT) == FALSE)
 		goto _return;
-	render->priv->play_state = DACP_PLAY_STOPPED;
+	render->priv->play_state = CONTROL_PLAY_STOPPED;
 
 _return:
 	gst_object_unref (render->priv->pipeline);
@@ -373,11 +377,11 @@ av_render_gst_init (AVRenderGst *render)
 
 	render->priv->host = NULL;
 	render->priv->port = 0;
-	render->priv->transport_protocol = DMAP_MDNS_BROWSER_TRANSPORT_PROTOCOL_TCP;
+	render->priv->transport_protocol = DMAP_MDNS_SERVICE_TRANSPORT_PROTOCOL_TCP;
 
 	render->priv->shuffle_state = FALSE;
-	render->priv->repeat_state  = DACP_REPEAT_NONE;
-	render->priv->play_state    = DACP_PLAY_STOPPED;
+	render->priv->repeat_state  = CONTROL_REPEAT_NONE;
+	render->priv->play_state    = CONTROL_PLAY_STOPPED;
 
 	av_render_gst_reset (render);
 }
@@ -536,8 +540,8 @@ av_render_gst_class_init (AVRenderGstClass *klass)
 					 g_param_spec_enum ("transport-protocol",
 					                    "transport-protocol",
 							    "transport-protocol",
-	                                                    DMAP_TYPE_DMAP_MDNS_BROWSER_TRANSPORT_PROTOCOL,
-							    DMAP_MDNS_BROWSER_TRANSPORT_PROTOCOL_TCP,
+	                                                    DMAP_TYPE_DMAP_MDNS_SERVICE_TRANSPORT_PROTOCOL,
+							    DMAP_MDNS_SERVICE_TRANSPORT_PROTOCOL_TCP,
 							    G_PARAM_READWRITE));
 }
 
