@@ -25,8 +25,8 @@
 
 struct DbBuilderGDirPrivate {
 	GSList          *monitor_list;
-	DMAPDb          *db;
-	DMAPContainerDb *container_db; // NULL if we don't want directory containers.
+	DmapDb          *db;
+	DmapContainerDb *container_db; // NULL if we don't want directory containers.
 };
 
 enum {
@@ -45,10 +45,16 @@ db_builder_gdir_set_property (GObject *object,
 
         switch (prop_id) {
 	case PROP_DB:
-		builder->priv->db = (DMAPDb *) g_value_get_pointer (value);
+		if (builder->priv->db) {
+			g_object_unref(builder->priv->db);
+		}
+		builder->priv->db = g_value_dup_object (value);
 		break;
 	case PROP_CONTAINER_DB:
-		builder->priv->container_db = (DMAPContainerDb *) g_value_get_pointer (value);
+		if (builder->priv->container_db) {
+			g_object_unref(builder->priv->container_db);
+		}
+		builder->priv->container_db = g_value_dup_object (value);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -66,10 +72,10 @@ db_builder_gdir_get_property (GObject *object,
 
 	switch (prop_id) {
 	case PROP_DB:
-                g_value_set_pointer (value, builder->priv->db);
+                g_value_set_object (value, builder->priv->db);
                 break;
         case PROP_CONTAINER_DB:
-                g_value_set_pointer (value, builder->priv->container_db);
+                g_value_set_object (value, builder->priv->container_db);
                 break;
 	default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -80,7 +86,7 @@ db_builder_gdir_get_property (GObject *object,
 static void
 db_builder_gdir_build_db_starting_at (DbBuilder *builder, 
 				      const char *dir,
-				      DMAPContainerRecord *container_record);
+				      DmapContainerRecord *container_record);
 
 static void
 db_builder_gdir_monitor_directory (DbBuilderGDir *builder, const char *path);
@@ -88,12 +94,12 @@ db_builder_gdir_monitor_directory (DbBuilderGDir *builder, const char *path);
 static void
 db_builder_gdir_handle_path (DbBuilderGDir *builder,
                              const char *path,
-                             DMAPContainerRecord *container_record)
+                             DmapContainerRecord *container_record)
 {
 	gchar *filename = g_path_get_basename (path);
 
 	if (g_file_test (path, G_FILE_TEST_IS_DIR)) {
-		DMAPContainerRecord *record = DMAP_CONTAINER_RECORD (g_object_new (TYPE_DMAPD_DMAP_CONTAINER_RECORD,
+		DmapContainerRecord *record = DMAP_CONTAINER_RECORD (g_object_new (TYPE_DMAPD_DMAP_CONTAINER_RECORD,
 		                                                                  "name", filename,
 		                                                                  "full-db", builder->priv->db,
 		                                                                   NULL));
@@ -133,9 +139,7 @@ db_builder_gdir_handle_path (DbBuilderGDir *builder,
 		}
 	}
 
-	if (NULL != filename) {
-		g_free (filename);
-	}
+	g_free (filename);
 }
 
 static void
@@ -214,7 +218,7 @@ done:
 static void
 db_builder_gdir_build_db_starting_at (DbBuilder *builder, 
 				      const char *dir,
-				      DMAPContainerRecord *container_record)
+				      DmapContainerRecord *container_record)
 {
 	g_assert (IS_DB_BUILDER_GDIR (builder));
 
@@ -278,16 +282,18 @@ static void db_builder_gdir_class_init (DbBuilderGDirClass *klass)
 
 	g_object_class_install_property (object_class,
                                          PROP_DB,
-                                         g_param_spec_pointer ("db",
-                                                               "DB",
-                                                               "DB object",
+                                         g_param_spec_object ("db",
+                                                              "DB",
+                                                              "DB object",
+	                                                       DMAP_TYPE_DB,
                                                                G_PARAM_READWRITE));
 
         g_object_class_install_property (object_class,
                                          PROP_CONTAINER_DB,
-                                         g_param_spec_pointer ("container-db",
-                                                               "Container DB",
-                                                               "Container DB object",
+                                         g_param_spec_object ("container-db",
+                                                              "Container DB",
+                                                              "Container DB object",
+	                                                       DMAP_TYPE_CONTAINER_DB,
                                                                G_PARAM_READWRITE));
 
 	g_type_class_add_private (klass, sizeof (DbBuilderGDir));
