@@ -36,7 +36,7 @@ G_DEFINE_TYPE (DbBuilder, db_builder, G_TYPE_OBJECT)
 void
 db_builder_build_db_starting_at (DbBuilder *builder,
 			   const char *dir,
-                           DMAPContainerRecord *container_record)
+                           DmapContainerRecord *container_record)
 {
 	return DB_BUILDER_GET_CLASS (builder)->build_db_starting_at (builder, dir, container_record);
 }
