@@ -31,9 +31,9 @@
 
 static const char *unknown = "Unknown";
 
-struct DmapdDAAPRecordPrivate {
+struct DmapdDmapAvRecordPrivate {
 	char *location;
-	GByteArray *hash;
+	GArray *hash;
 	guint64 filesize;
 	const char *format;	 	/* Format, possibly after transcoding. */
 	gint mediakind;
@@ -84,7 +84,7 @@ dmapd_daap_record_set_property (GObject *object,
 				const GValue *value,
 				GParamSpec *pspec)
 {
-	DmapdDAAPRecord *record = DMAPD_DAAP_RECORD (object);
+	DmapdDmapAvRecord *record = DMAPD_DMAP_AV_RECORD (object);
 
 	switch (prop_id) {
 		const char *str;
@@ -93,10 +93,10 @@ dmapd_daap_record_set_property (GObject *object,
 			record->priv->location = g_value_dup_string (value);
 			break;
 		case PROP_HASH:
-                        if (record->priv->hash) {
-                                g_byte_array_unref (record->priv->hash);
-                        }
-                        record->priv->hash = g_byte_array_ref (g_value_get_pointer (value));
+			if (record->priv->hash) {
+				g_array_unref(record->priv->hash);
+			}
+                        record->priv->hash = g_value_get_boxed(value);
                         break;
 		case PROP_TITLE:
 			g_free (record->priv->title);
@@ -175,14 +175,14 @@ dmapd_daap_record_get_property (GObject *object,
 				GValue *value,
 				GParamSpec *pspec)
 {
-	DmapdDAAPRecord *record = DMAPD_DAAP_RECORD (object);
+	DmapdDmapAvRecord *record = DMAPD_DMAP_AV_RECORD (object);
 
 	switch (prop_id) {
 		case PROP_LOCATION:
 			g_value_set_static_string (value, record->priv->location);
 			break;
 		case PROP_HASH:
-                        g_value_set_pointer (value, record->priv->hash);
+                        g_value_set_boxed (value, record->priv->hash);
                         break;
 		case PROP_TITLE:
 			g_value_set_static_string (value, record->priv->title);
@@ -246,9 +246,9 @@ dmapd_daap_record_get_property (GObject *object,
 	}
 }
 
-gboolean dmapd_daap_record_itunes_compat (DAAPRecord *record)
+gboolean dmapd_daap_record_itunes_compat (DmapAvRecord *record)
 {
-	const gchar *format = DMAPD_DAAP_RECORD (record)->priv->format;
+	const gchar *format = DMAPD_DMAP_AV_RECORD (record)->priv->format;
 
 	if (! strcmp (format, "mp3"))
 		return TRUE;
@@ -256,27 +256,27 @@ gboolean dmapd_daap_record_itunes_compat (DAAPRecord *record)
 		return FALSE;
 }
 
-GInputStream *dmapd_daap_record_read (DAAPRecord *record, GError **error)
+GInputStream *dmapd_daap_record_read (DmapAvRecord *record, GError **error)
 {
 	GFile *file;
 	GInputStream *fnval = NULL;
 
-	file = g_file_new_for_uri (DMAPD_DAAP_RECORD (record)->priv->location);
+	file = g_file_new_for_uri (DMAPD_DMAP_AV_RECORD (record)->priv->location);
 	g_assert (file);
 	fnval = G_INPUT_STREAM (g_file_read (file, NULL, error));
 
 	return fnval;
 }
 
-static GByteArray *
-dmapd_daap_record_to_blob (DMAPRecord *record)
+static GArray *
+dmapd_daap_record_to_blob (DmapRecord *record)
 {
 	/* FIXME: not endian safe. Don't write with one endianness and
 	 * read with another
 	 */
 	
-	DmapdDAAPRecordPrivate *priv = DMAPD_DAAP_RECORD (record)->priv;
-	GByteArray *blob = g_byte_array_new ();
+	DmapdDmapAvRecordPrivate *priv = DMAPD_DMAP_AV_RECORD (record)->priv;
+	GArray *blob = g_array_new (FALSE, FALSE, 1);
 
 	/* NOTE: do not store ID in the blob. */
 
@@ -292,9 +292,9 @@ dmapd_daap_record_to_blob (DMAPRecord *record)
 	blob_add_string (blob, priv->location);
 
 	blob_add_atomic (blob, (const guint8 *) &(priv->hash->len), sizeof (priv->hash->len));
-	g_byte_array_append (blob, priv->hash->data, priv->hash->len);
+	g_array_append_vals (blob, priv->hash->data, priv->hash->len);
 
-	blob_add_atomic   (blob, (const guint8 *) &(priv->filesize),
+	blob_add_atomic (blob, (const guint8 *) &(priv->filesize),
 			   sizeof (priv->filesize));
 
 	blob_add_string (blob, priv->format);
@@ -328,23 +328,23 @@ dmapd_daap_record_to_blob (DMAPRecord *record)
 }
 
 static gboolean
-dmapd_daap_record_set_from_blob (DMAPRecord *_record, GByteArray *blob)
+dmapd_daap_record_set_from_blob (DmapRecord *_record, GArray *blob)
 {
 	struct stat buf;
 	gboolean fnval = FALSE;
-	DmapdDAAPRecord *record = NULL;
+	DmapdDmapAvRecord *record = NULL;
 	GFile *file = NULL;
 	gchar *path = NULL;
 	GFileInputStream *stream = NULL;
 	GError *error = NULL;
-	guint8 *ptr = blob->data;
+	gchar *ptr = blob->data;
 
 	char *version;
 	guint size;
 	guint64 filesize;
 	char *location;
 	char *format;
-	GByteArray *hash = NULL;
+	GArray *hash = NULL;
 	guchar hash2[DMAP_HASH_SIZE];
 	char *title;
 	char *songalbum;
@@ -378,12 +378,12 @@ dmapd_daap_record_set_from_blob (DMAPRecord *_record, GByteArray *blob)
         }
         ptr += sizeof (size);
 
-        hash = g_byte_array_sized_new (size);
+        hash = g_array_sized_new (FALSE, FALSE, 1, size);
 	if (NULL == hash) {
 		g_warning ("Error allocating array for hash\n");
 		goto _done;
 	}
-        g_byte_array_append (hash, ptr, size);
+        g_array_append_vals (hash, ptr, size);
         ptr += size;
 
 	filesize = *(guint64 *) ptr;
@@ -469,7 +469,7 @@ dmapd_daap_record_set_from_blob (DMAPRecord *_record, GByteArray *blob)
 		}
 	}
 
-	record = DMAPD_DAAP_RECORD (_record);
+	record = DMAPD_DMAP_AV_RECORD (_record);
 
 	g_object_set (record, "year", year,
 	                      "filesize", filesize,
@@ -506,24 +506,24 @@ _done:
 	}
 
 	if (NULL != hash) {
-		g_byte_array_unref (hash);
+		g_array_unref (hash);
 	}
 
 	return fnval;
 }
 
-static void dmapd_daap_record_init (DmapdDAAPRecord *record)
+static void dmapd_daap_record_init (DmapdDmapAvRecord *record)
 {
-	record->priv = DMAPD_DAAP_RECORD_GET_PRIVATE (record);
+	record->priv = DMAPD_DMAP_AV_RECORD_GET_PRIVATE (record);
 }
 
 static void dmapd_daap_record_finalize (GObject *object);
 
-static void dmapd_daap_record_class_init (DmapdDAAPRecordClass *klass)
+static void dmapd_daap_record_class_init (DmapdDmapAvRecordClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (DmapdDAAPRecordPrivate));
+	g_type_class_add_private (klass, sizeof (DmapdDmapAvRecordPrivate));
 
 	gobject_class->set_property = dmapd_daap_record_set_property;	
 	gobject_class->get_property = dmapd_daap_record_get_property;	
@@ -553,9 +553,9 @@ static void dmapd_daap_record_class_init (DmapdDAAPRecordClass *klass)
 
 static void dmapd_daap_record_daap_iface_init (gpointer iface, gpointer data)
 {
-	DAAPRecordIface *daap_record = iface;
+	DmapAvRecordInterface *daap_record = iface;
 
-	g_assert (G_TYPE_FROM_INTERFACE (daap_record) == DAAP_TYPE_RECORD);
+	g_assert (G_TYPE_FROM_INTERFACE (daap_record) == DMAP_TYPE_AV_RECORD);
 
 	daap_record->itunes_compat = dmapd_daap_record_itunes_compat;
 	daap_record->read = dmapd_daap_record_read;
@@ -563,7 +563,7 @@ static void dmapd_daap_record_daap_iface_init (gpointer iface, gpointer data)
 
 static void dmapd_daap_record_dmap_iface_init (gpointer iface, gpointer data)
 {
-	DMAPRecordIface *dmap_record = iface;
+	DmapRecordInterface *dmap_record = iface;
 
 	g_assert (G_TYPE_FROM_INTERFACE (dmap_record) == DMAP_TYPE_RECORD);
 
@@ -572,14 +572,14 @@ static void dmapd_daap_record_dmap_iface_init (gpointer iface, gpointer data)
 }
 
 
-G_DEFINE_TYPE_WITH_CODE (DmapdDAAPRecord, dmapd_daap_record, G_TYPE_OBJECT, 
-			 G_IMPLEMENT_INTERFACE (DAAP_TYPE_RECORD, dmapd_daap_record_daap_iface_init)
+G_DEFINE_TYPE_WITH_CODE (DmapdDmapAvRecord, dmapd_daap_record, G_TYPE_OBJECT, 
+			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_AV_RECORD, dmapd_daap_record_daap_iface_init)
 			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD, dmapd_daap_record_dmap_iface_init))
 
 static void
 dmapd_daap_record_finalize (GObject *object)
 {
-	DmapdDAAPRecord *record = DMAPD_DAAP_RECORD (object);
+	DmapdDmapAvRecord *record = DMAPD_DMAP_AV_RECORD (object);
 
 	g_debug ("Free'ing record");
 
@@ -594,14 +594,14 @@ dmapd_daap_record_finalize (GObject *object)
 	G_OBJECT_CLASS (dmapd_daap_record_parent_class)->finalize (object);
 }
 
-DmapdDAAPRecord *dmapd_daap_record_new (const char *path, AVMetaReader *reader)
+DmapdDmapAvRecord *dmapd_daap_record_new (const char *path, AVMetaReader *reader)
 {
-	DmapdDAAPRecord *record = NULL;
+	DmapdDmapAvRecord *record = NULL;
 	guchar hash_buf[DMAP_HASH_SIZE];
 	struct stat buf;
 	char *title = NULL;
 	char *location = NULL;
-	GByteArray *hash = NULL;
+	GArray *hash = NULL;
 
 	if (path) {
 		location = g_filename_to_uri (path, NULL, NULL);
@@ -616,7 +616,7 @@ DmapdDAAPRecord *dmapd_daap_record_new (const char *path, AVMetaReader *reader)
 			goto _done;
 		}
 
-		hash = g_byte_array_sized_new (DMAP_HASH_SIZE);
+		hash = g_array_sized_new (FALSE, FALSE, 1, DMAP_HASH_SIZE);
 		if (NULL == hash) {
 			g_warning ("Error allocating memory for record's hash field\n");
 			goto _done;
@@ -631,9 +631,9 @@ DmapdDAAPRecord *dmapd_daap_record_new (const char *path, AVMetaReader *reader)
 			memset(hash_buf, 0x00, DMAP_HASH_SIZE);
 		}
 
-		g_byte_array_append (hash, hash_buf, DMAP_HASH_SIZE);
+		g_array_append_vals (hash, hash_buf, DMAP_HASH_SIZE);
 
-		record = DMAPD_DAAP_RECORD (g_object_new (TYPE_DMAPD_DAAP_RECORD, NULL));
+		record = DMAPD_DMAP_AV_RECORD (g_object_new (TYPE_DMAPD_DMAP_AV_RECORD, NULL));
 		if (NULL == record) {
 			g_warning ("Error allocating memory for record\n");
 			goto _done;
@@ -662,7 +662,7 @@ DmapdDAAPRecord *dmapd_daap_record_new (const char *path, AVMetaReader *reader)
 		                      "disc",        1,
 		                       NULL);
 
-		if (! av_meta_reader_read (AV_META_READER (reader), DAAP_RECORD (record), path)) {
+		if (! av_meta_reader_read (AV_META_READER (reader), DMAP_AV_RECORD (record), path)) {
 			g_object_unref (record);
 			record = NULL;
 			goto _done;
@@ -672,7 +672,7 @@ DmapdDAAPRecord *dmapd_daap_record_new (const char *path, AVMetaReader *reader)
 		record->priv->firstseen = 1;	/* FIXME */
 		record->priv->bitrate = 128;	/* FIXME, from codec decoder */
 	} else {
-		record = DMAPD_DAAP_RECORD (g_object_new (TYPE_DMAPD_DAAP_RECORD, NULL));
+		record = DMAPD_DMAP_AV_RECORD (g_object_new (TYPE_DMAPD_DMAP_AV_RECORD, NULL));
 		if (NULL == record) {
 			g_warning ("Error allocating memory for record");
 			goto _done;
@@ -690,7 +690,7 @@ _done:
 	}
 
 	if (NULL != hash) {
-		g_byte_array_unref (hash);
+		g_array_unref (hash);
 	}
 
 	return record;
