@@ -27,14 +27,14 @@
 #include "dmapd-dpap-record.h"
 #include "photo-meta-reader.h"
 
-struct DmapdDPAPRecordPrivate {
+struct DmapdDmapImageRecordPrivate {
 	char *location;
-	GByteArray *hash;
+	GArray *hash;
 	gint largefilesize;
 	gint creationdate;
 	gint rating;
 	char *filename;
-	GByteArray *thumbnail;
+	GArray *thumbnail;
 	const char *aspectratio;
 	gint height;
 	gint width;
@@ -66,7 +66,7 @@ dmapd_dpap_record_set_property (GObject *object,
 				const GValue *value,
 				GParamSpec *pspec)
 {
-	DmapdDPAPRecord *record = DMAPD_DPAP_RECORD (object);
+	DmapdDmapImageRecord *record = DMAPD_DPAP_RECORD (object);
 
 	switch (prop_id) {
 		case PROP_LOCATION:
@@ -75,9 +75,9 @@ dmapd_dpap_record_set_property (GObject *object,
 			break;
 		case PROP_HASH:
 			if (record->priv->hash) {
-				g_byte_array_unref (record->priv->hash);
+				g_array_unref(record->priv->hash);
 			}
-			record->priv->hash = g_byte_array_ref (g_value_get_pointer (value));
+			record->priv->hash = g_value_get_boxed (value);
 			break;
 		case PROP_LARGE_FILESIZE:
 			record->priv->largefilesize = g_value_get_int (value);
@@ -112,9 +112,9 @@ dmapd_dpap_record_set_property (GObject *object,
 			break;
 		case PROP_THUMBNAIL:
 			if (record->priv->thumbnail) {
-				g_byte_array_unref (record->priv->thumbnail);
+				g_array_unref(record->priv->thumbnail);
 			}
-			record->priv->thumbnail = g_byte_array_ref (g_value_get_pointer (value));
+			record->priv->thumbnail = g_value_dup_boxed (value);
 			break;
 		case PROP_MTIME:
 			record->priv->mtime = g_value_get_int (value);
@@ -132,14 +132,14 @@ dmapd_dpap_record_get_property (GObject *object,
 				GValue *value,
 				GParamSpec *pspec)
 {
-	DmapdDPAPRecord *record = DMAPD_DPAP_RECORD (object);
+	DmapdDmapImageRecord *record = DMAPD_DPAP_RECORD (object);
 
 	switch (prop_id) {
 		case PROP_LOCATION:
 			g_value_set_static_string (value, record->priv->location);
 			break;
 		case PROP_HASH:
-			g_value_set_pointer (value, record->priv->hash);
+			g_value_set_boxed (value, record->priv->hash);
 			break;
 		case PROP_LARGE_FILESIZE:
 			g_value_set_int (value, record->priv->largefilesize);
@@ -169,7 +169,7 @@ dmapd_dpap_record_get_property (GObject *object,
 			g_value_set_static_string (value, record->priv->comments);
 			break;
 		case PROP_THUMBNAIL:
-			g_value_set_pointer (value, record->priv->thumbnail);
+			g_value_set_boxed (value, record->priv->thumbnail);
 			break;
 		case PROP_MTIME:
 			g_value_set_int (value, record->priv->mtime);
@@ -181,7 +181,7 @@ dmapd_dpap_record_get_property (GObject *object,
 	}
 }
 
-GInputStream *dmapd_dpap_record_read (DPAPRecord *record, GError **error)
+GInputStream *dmapd_dpap_record_read (DmapImageRecord *record, GError **error)
 {
         GFile *file;
         GInputStream *stream;
@@ -194,15 +194,15 @@ GInputStream *dmapd_dpap_record_read (DPAPRecord *record, GError **error)
         return stream;
 }
 
-static GByteArray *
-dmapd_dpap_record_to_blob (DMAPRecord *record)
+static GArray *
+dmapd_dpap_record_to_blob (DmapRecord *record)
 {
 	/* FIXME: not endian safe. Don't write with one endianness and 
 	 * read with another
 	 */
 
-	DmapdDPAPRecordPrivate *priv = DMAPD_DPAP_RECORD (record)->priv;
-	GByteArray *blob = g_byte_array_new ();
+	DmapdDmapImageRecordPrivate *priv = DMAPD_DPAP_RECORD (record)->priv;
+	GArray *blob = g_array_new (FALSE, FALSE, 1);
 
 	/* NOTE: do not store ID in the blob. */
 
@@ -218,7 +218,7 @@ dmapd_dpap_record_to_blob (DMAPRecord *record)
 	blob_add_string (blob, priv->location);
 
 	blob_add_atomic (blob, (const guint8 *) &(priv->hash->len), sizeof (priv->hash->len));
-	g_byte_array_append (blob, priv->hash->data, priv->hash->len);
+	g_array_append_vals (blob, priv->hash->data, priv->hash->len);
 
 	blob_add_atomic (blob, (const guint8 *) &(priv->largefilesize),
 			 sizeof (priv->largefilesize));
@@ -231,7 +231,7 @@ dmapd_dpap_record_to_blob (DMAPRecord *record)
 		blob_add_atomic (blob, (const guint8 *) &(priv->thumbnail->len),
 				 sizeof (priv->thumbnail->len));
 
-		g_byte_array_append (blob,
+		g_array_append_vals (blob,
 				     priv->thumbnail->data,
 				     priv->thumbnail->len);
 	} else {
@@ -254,27 +254,27 @@ dmapd_dpap_record_to_blob (DMAPRecord *record)
 }
 
 static gboolean
-dmapd_dpap_record_set_from_blob (DMAPRecord *_record, GByteArray *blob)
+dmapd_dpap_record_set_from_blob (DmapRecord *_record, GArray *blob)
 {
 	struct stat buf;
 	gboolean fnval = FALSE;
-	DmapdDPAPRecord *record = NULL;
+	DmapdDmapImageRecord *record = NULL;
 	GFile *file = NULL;
 	gchar *path = NULL;
 	GFileInputStream *stream = NULL;
 	GError *error = NULL;
-	guint8 *ptr = blob->data;
+	gchar *ptr = blob->data;
 
 	char *version;
 	guint size;
 	char *location;
-	GByteArray *hash = NULL;
+	GArray *hash = NULL;
 	guchar hash2[DMAP_HASH_SIZE];
 	gint large_filesize;
 	gint creation_date;
 	gint rating;
 	char *filename;
-	GByteArray *thumbnail = NULL;
+	GArray *thumbnail = NULL;
 	char *aspect_ratio;
 	gint pixel_height;
 	gint pixel_width;
@@ -299,12 +299,12 @@ dmapd_dpap_record_set_from_blob (DMAPRecord *_record, GByteArray *blob)
 	}
 	ptr += sizeof (size);
 
-	hash = g_byte_array_sized_new (size);
+	hash = g_array_sized_new (FALSE, FALSE, 1, size);
 	if (NULL == hash) {
                 g_warning ("Error allocating array for hash\n");
                 goto _done;
         }
-	g_byte_array_append (hash, ptr, size);
+	g_array_append_vals (hash, ptr, size);
 	ptr += size;
 
 	large_filesize = *(gint *) ptr;
@@ -323,12 +323,12 @@ dmapd_dpap_record_set_from_blob (DMAPRecord *_record, GByteArray *blob)
 	ptr += sizeof (size);
 
 	if (size) {
-		thumbnail = g_byte_array_sized_new (size);
+		thumbnail = g_array_sized_new (FALSE, FALSE, 1, size);
 		if (NULL == thumbnail) {
 			g_warning ("Error allocating array for thumbnail\n");
 			goto _done;
 		}
-		g_byte_array_append (thumbnail, ptr, size);
+		g_array_append_vals (thumbnail, ptr, size);
 		ptr += size;
 	}
 
@@ -404,7 +404,7 @@ dmapd_dpap_record_set_from_blob (DMAPRecord *_record, GByteArray *blob)
 	if (NULL != thumbnail) {
 		g_object_set (record, "thumbnail", thumbnail, NULL);
 	} else {
-		g_object_set (record, "thumbnail",  g_byte_array_sized_new (0), NULL);
+		g_object_set (record, "thumbnail",  g_array_sized_new (FALSE, FALSE, 1, 0), NULL);
 	}
 
 	fnval = TRUE;	
@@ -424,28 +424,28 @@ _done:
         }
 
 	if (NULL != hash) {
-		g_byte_array_unref (hash);
+		g_array_unref (hash);
 	}
 
 	if (NULL != thumbnail) {
-		g_byte_array_unref (thumbnail);
+		g_array_unref (thumbnail);
 	}
 
 	return fnval;
 }
 
-static void dmapd_dpap_record_init (DmapdDPAPRecord *record)
+static void dmapd_dpap_record_init (DmapdDmapImageRecord *record)
 {
 	record->priv = DMAPD_DPAP_RECORD_GET_PRIVATE (record);
 }
 
 static void dmapd_dpap_record_finalize (GObject *object);
 
-static void dmapd_dpap_record_class_init (DmapdDPAPRecordClass *klass)
+static void dmapd_dpap_record_class_init (DmapdDmapImageRecordClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (DmapdDPAPRecordPrivate));
+	g_type_class_add_private (klass, sizeof (DmapdDmapImageRecordPrivate));
 
 	gobject_class->set_property = dmapd_dpap_record_set_property;
 	gobject_class->get_property = dmapd_dpap_record_get_property;
@@ -475,16 +475,16 @@ static void dmapd_dpap_record_class_init (DmapdDPAPRecordClass *klass)
 
 static void dmapd_dpap_record_dpap_iface_init (gpointer iface, gpointer data)
 {
-	DPAPRecordIface *dpap_record = iface;
+	DmapImageRecordInterface *dpap_record = iface;
 
-	g_assert (G_TYPE_FROM_INTERFACE (dpap_record) == DPAP_TYPE_RECORD);
+	g_assert (G_TYPE_FROM_INTERFACE (dpap_record) == DMAP_TYPE_IMAGE_RECORD);
 
 	dpap_record->read = dmapd_dpap_record_read;
 }
 
 static void dmapd_dpap_record_dmap_iface_init (gpointer iface, gpointer data)
 {
-	DMAPRecordIface *dmap_record = iface;
+	DmapRecordInterface *dmap_record = iface;
 
 	g_assert (G_TYPE_FROM_INTERFACE (dmap_record) == DMAP_TYPE_RECORD);
 
@@ -493,14 +493,14 @@ static void dmapd_dpap_record_dmap_iface_init (gpointer iface, gpointer data)
 }
 
 
-G_DEFINE_TYPE_WITH_CODE (DmapdDPAPRecord, dmapd_dpap_record, G_TYPE_OBJECT, 
-			 G_IMPLEMENT_INTERFACE (DPAP_TYPE_RECORD, dmapd_dpap_record_dpap_iface_init)
+G_DEFINE_TYPE_WITH_CODE (DmapdDmapImageRecord, dmapd_dpap_record, G_TYPE_OBJECT, 
+			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_IMAGE_RECORD, dmapd_dpap_record_dpap_iface_init)
 			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD, dmapd_dpap_record_dmap_iface_init))
 
 static void
 dmapd_dpap_record_finalize (GObject *object)
 {
-        DmapdDPAPRecord *record = DMAPD_DPAP_RECORD (object);
+        DmapdDmapImageRecord *record = DMAPD_DPAP_RECORD (object);
 
 	g_debug ("Free'ing record");
 
@@ -512,23 +512,23 @@ dmapd_dpap_record_finalize (GObject *object)
 	g_free (record->priv->comments);
 
 	if (record->priv->hash) {
-		g_byte_array_unref (record->priv->hash);
+		g_array_unref (record->priv->hash);
 	}
 
 	if (record->priv->thumbnail) {
-		g_byte_array_unref (record->priv->thumbnail);
+		g_array_unref (record->priv->thumbnail);
 	}
 
 	G_OBJECT_CLASS (dmapd_dpap_record_parent_class)->finalize (object);
 }
 
-DmapdDPAPRecord *dmapd_dpap_record_new (const char *path, gpointer reader)
+DmapdDmapImageRecord *dmapd_dpap_record_new (const char *path, gpointer reader)
 {
-	DmapdDPAPRecord *record = NULL;
+	DmapdDmapImageRecord *record = NULL;
 	guchar hash_buf[DMAP_HASH_SIZE];
 	struct stat buf;
 	char *location = NULL;
-	GByteArray *hash = NULL;
+	GArray *hash = NULL;
 
 	if (path) {
 		location = g_filename_to_uri (path, NULL, NULL);
@@ -537,7 +537,7 @@ DmapdDPAPRecord *dmapd_dpap_record_new (const char *path, gpointer reader)
                         goto _done;
                 }
 
-		hash = g_byte_array_sized_new (DMAP_HASH_SIZE);
+		hash = g_array_sized_new (FALSE, FALSE, 1, DMAP_HASH_SIZE);
                 if (NULL == hash) {
                         g_warning ("Error allocating memory for record's hash field\n");
                         goto _done;
@@ -552,7 +552,7 @@ DmapdDPAPRecord *dmapd_dpap_record_new (const char *path, gpointer reader)
 			memset(hash_buf, 0x00, DMAP_HASH_SIZE);
 		}
 
-		g_byte_array_append (hash, hash_buf, DMAP_HASH_SIZE);
+		g_array_append_vals (hash, hash_buf, DMAP_HASH_SIZE);
 
 		record = DMAPD_DPAP_RECORD (g_object_new (TYPE_DMAPD_DPAP_RECORD, NULL));
 		if (NULL == record) {
@@ -573,7 +573,7 @@ DmapdDPAPRecord *dmapd_dpap_record_new (const char *path, gpointer reader)
                                       "hash",     hash,
 		                       NULL);
 
-		if (! photo_meta_reader_read (PHOTO_META_READER (reader), DPAP_RECORD (record), path)) {
+		if (! photo_meta_reader_read (PHOTO_META_READER (reader), DMAP_IMAGE_RECORD (record), path)) {
 			g_object_unref (record);
 			record = NULL;
 			goto _done;
@@ -592,7 +592,7 @@ _done:
         }
 
         if (NULL != hash) {
-                g_byte_array_unref (hash);
+                g_array_unref (hash);
         }
 
 	return record;
