@@ -39,30 +39,30 @@ enum {
 
 static GMainLoop *loop;
 
-static gchar *service_name = NULL;
+static gchar *_service_name = NULL;
 static guint iteration_count = ~0;
 
 static GOptionEntry entries[] = {
-        { "service-name", 's', 0, G_OPTION_ARG_STRING, &service_name, "Server name to connect to; default is to query user interactively", NULL },
+        { "service-name", 's', 0, G_OPTION_ARG_STRING, &_service_name, "Server name to connect to; default is to query user interactively", NULL },
         { "iteration-count", 'i', 0, G_OPTION_ARG_INT, &iteration_count, "Number of times to hit server; default is forever", NULL },
 	{ NULL }
 };
 
 static void
-create_connection (const DMAPMdnsBrowserServiceType protocol,
+create_connection (const DmapMdnsServiceType protocol,
 		   const char *name,
 		   const char *host,
 		   const guint port);
 
 static void
-process_record (gpointer id, DMAPRecord *record, gpointer user_data)
+process_record (gpointer id, DmapRecord *record, gpointer user_data)
 {
 	guint status;
 	SoupSession *soup_session;
 	SoupMessage *soup_message;
 	gchar *location = NULL, *desc1 = NULL, *desc2 = NULL;
 
-	if (IS_DAAP_RECORD (record)) {
+	if (IS_DMAP_AV_RECORD (record)) {
 		/* FIXME: print all record properties; need DAAP and DPAP version: */
 		g_object_get (record,
 			     "location",   &location,
@@ -75,7 +75,7 @@ process_record (gpointer id, DMAPRecord *record, gpointer user_data)
 		g_assert (desc2);
 
 		g_print ("%d: %s %s %s\n", GPOINTER_TO_UINT (id), desc1, desc2, location);
-	} else if (IS_DPAP_RECORD (record)) {
+	} else if (IS_DMAP_IMAGE_RECORD (record)) {
 		/* FIXME: print all record properties; need DAAP and DPAP version: */
 		g_object_get (record,
 			     "location", &location,
@@ -112,23 +112,23 @@ process_record (gpointer id, DMAPRecord *record, gpointer user_data)
 	g_object_unref (soup_message);
 }
 
-static DMAPMdnsBrowserServiceType
-get_service_type (DMAPConnection *connection)
+static DmapMdnsServiceType
+get_service_type (DmapConnection *connection)
 {
-	if (IS_DAAP_CONNECTION (connection)) {
-		return DMAP_MDNS_BROWSER_SERVICE_TYPE_DAAP;
-	} else if (IS_DPAP_CONNECTION (connection)) {
-		return DMAP_MDNS_BROWSER_SERVICE_TYPE_DPAP;
+	if (IS_DMAP_AV_CONNECTION (connection)) {
+		return DMAP_MDNS_SERVICE_TYPE_DAAP;
+	} else if (IS_DMAP_IMAGE_CONNECTION (connection)) {
+		return DMAP_MDNS_SERVICE_TYPE_DPAP;
 	} else {
 		g_error ("Bad connection");
 	}
 }
 
 static void
-connected_cb (DMAPConnection *connection,
+connected_cb (DmapConnection *connection,
 	      gboolean        result,
 	      const char     *reason,
-	      DMAPDb         *db)
+	      DmapDb         *db)
 {
 	guint port;
 	char *name, *host;
@@ -137,7 +137,7 @@ connected_cb (DMAPConnection *connection,
 	g_print ("Connection cb., DB has %lu entries\n", dmap_db_count (db));
 	g_print ("Iteration %d...\n", count++);
 
-	dmap_db_foreach (db, (GHFunc) process_record, NULL);
+	dmap_db_foreach (db, (DmapIdRecordFunc) process_record, NULL);
 
 	g_object_get (connection,
 		     "name", &name,
@@ -163,63 +163,74 @@ connected_cb (DMAPConnection *connection,
 }
 
 static void
-create_connection (const DMAPMdnsBrowserServiceType protocol,
+create_connection (const DmapMdnsServiceType protocol,
 		   const char *name,
 		   const char *host,
 		   const guint port)
 {
-	DMAPRecordFactory *factory;
-	DMAPConnection *conn;
-	DMAPDb *db;
+	DmapRecordFactory *factory;
+	DmapConnection *conn;
+	DmapDb *db;
 
 	db = DMAP_DB (g_object_new (TYPE_DMAPD_DMAP_DB_GHASHTABLE, NULL));
 	if (db == NULL) {
 		g_error ("Error creating DB");
 	}
 
-	/* FIXME: switch on DMAP_MDNS_BROWSER_SERVICE_TYPE_DAAP, _DPAP, _DACP or _INVALID */
-	if (protocol == DMAP_MDNS_BROWSER_SERVICE_TYPE_DAAP) {
-		factory = DMAP_RECORD_FACTORY (g_object_new (TYPE_DMAPD_DAAP_RECORD_FACTORY, NULL));
+	/* FIXME: switch on DMAP_MDNS_SERVICE_TYPE_DAAP, _DPAP, _DACP or _INVALID */
+	if (protocol == DMAP_MDNS_SERVICE_TYPE_DAAP) {
+		factory = DMAP_RECORD_FACTORY (g_object_new (TYPE_DMAPD_DMAP_AV_RECORD_FACTORY, NULL));
 		if (factory == NULL) {
 			g_error ("Error creating record factory");
 		}
-		conn = DMAP_CONNECTION (daap_connection_new (name, host, port, db, factory));
+		conn = DMAP_CONNECTION (dmap_av_connection_new (name, host, port, db, factory));
 	} else {
 		factory = DMAP_RECORD_FACTORY (g_object_new (TYPE_DMAPD_DPAP_RECORD_FACTORY, NULL));
 		if (factory == NULL) {
 			g_error ("Error creating record factory");
 		}
-		conn = DMAP_CONNECTION (dpap_connection_new (name, host, port, db, factory));
+		conn = DMAP_CONNECTION (dmap_image_connection_new (name, host, port, db, factory));
 	}
-	dmap_connection_connect (DMAP_CONNECTION (conn), (DMAPConnectionCallback) connected_cb, db);
+	dmap_connection_start (DMAP_CONNECTION (conn), (DmapConnectionFunc) connected_cb, db);
 }
 
 static void
-service_added_cb (DMAPMdnsBrowser *browser,
-                  DMAPMdnsBrowserService *service,
+service_added_cb (DmapMdnsBrowser *browser,
+                  DmapMdnsService *service,
                   gpointer user_data)
 {
 	char answer, newline;
 
-	if (NULL == service_name) {
+	gchar *service_name = NULL, *name = NULL, *host = NULL;
+	guint port = 0;
+	gboolean password_protected = FALSE;
+
+	g_object_get(service, "service-name", &service_name,
+	                      "name", &name,
+	                      "host", &host,
+	                      "port", &port,
+	                      "password-protected", &password_protected,
+	                       NULL);
+
+	if (NULL == _service_name) {
 		fprintf (stdout,
 		    "service added %s:%s:%s:%d (%s)\n",
-		     service->service_name,
-		     service->name,
-		     service->host,
-		     service->port,
-		     service->password_protected ? "protected" : "not protected");
+		     service_name,
+		     name,
+		     host,
+		     port,
+		     password_protected ? "protected" : "not protected");
 		fprintf (stdout, "Stress test this service [Y|N]? ");
 		fscanf (stdin, "%c%c", &answer, &newline);
 	} else {
-		answer = strcmp (service->service_name, service_name) ? 'N' : 'Y';
+		answer = strcmp (_service_name, service_name) ? 'N' : 'Y';
 	}
 
 	if (answer == 'Y') {
 		create_connection (dmap_mdns_browser_get_service_type (browser),
-				   service->name,
-				   service->host,
-				   service->port);
+				   name,
+				   host,
+				   port);
 	}
 }
 
@@ -234,7 +245,7 @@ debug_null (const char *log_domain,
 int main(int argc, char **argv)
 {
 	GOptionContext *context;
-	DMAPMdnsBrowser *browserDAAP, *browserDPAP;
+	DmapMdnsBrowser *browserDAAP, *browserDPAP;
 	GError *error = NULL;
 
 	stringleton_init ();
@@ -251,14 +262,14 @@ int main(int argc, char **argv)
 
 	loop = g_main_loop_new (NULL, FALSE);
 
-	browserDAAP = dmap_mdns_browser_new (DMAP_MDNS_BROWSER_SERVICE_TYPE_DAAP);
+	browserDAAP = dmap_mdns_browser_new (DMAP_MDNS_SERVICE_TYPE_DAAP);
 
 	g_signal_connect (G_OBJECT (browserDAAP),
 		         "service-added",
 		          G_CALLBACK (service_added_cb),
 		          NULL);
 
-	browserDPAP = dmap_mdns_browser_new (DMAP_MDNS_BROWSER_SERVICE_TYPE_DPAP);
+	browserDPAP = dmap_mdns_browser_new (DMAP_MDNS_SERVICE_TYPE_DPAP);
 
 	g_signal_connect (G_OBJECT (browserDPAP),
 		         "service-added",
