@@ -394,21 +394,21 @@ photo_meta_reader_vips_get_str (VipsImage *im, const char *field)
 }
 
 static gboolean
-photo_meta_reader_vips_read (PhotoMetaReader *reader, DPAPRecord *record, const gchar *path)
+photo_meta_reader_vips_read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path)
 {
 	g_assert (IS_PHOTO_META_READER (reader));
-	g_assert (IS_DPAP_RECORD (record));
+	g_assert (IS_DMAP_IMAGE_RECORD (record));
 	g_assert (NULL != path);
 
 	VipsObject *process;
-	const gchar *str            = NULL;
-	VipsImage *im               = NULL;
-	VipsImage *thumb            = NULL;
-	VipsFormatClass *format     = NULL;
-	gchar *basename             = NULL;
-	gchar *aspect_ratio         = NULL;
-	void *thumbnail_data        = NULL;
-	GByteArray *thumbnail_array = NULL;
+	const gchar *str        = NULL;
+	VipsImage *im           = NULL;
+	VipsImage *thumb        = NULL;
+	VipsFormatClass *format = NULL;
+	gchar *basename         = NULL;
+	gchar *aspect_ratio     = NULL;
+	void *thumbnail_data    = NULL;
+	GArray *thumbnail_array = NULL;
 	gboolean fnval = FALSE;
 	struct stat buf;
 	gsize thumbnail_size = 0;
@@ -501,16 +501,16 @@ photo_meta_reader_vips_read (PhotoMetaReader *reader, DPAPRecord *record, const
 
 	if (thumbnail_shrink (reader, process, thumb, &thumbnail_data, &thumbnail_size)) {
 		g_debug ("    Thumbnail is %ld bytes.", thumbnail_size);
-		thumbnail_array = g_byte_array_sized_new (thumbnail_size);
+		thumbnail_array = g_array_sized_new (FALSE, FALSE, 1, thumbnail_size);
 		if (NULL == thumbnail_array) {
 			// FIXME: I think the thumbnail prop. MUST be non-NULL;
 			//        if not, this could be cleaned up and non-fatal.
 			g_error ("Could not allocate memory for thumbnail array\n");
 		} else {
-			g_byte_array_append (thumbnail_array, thumbnail_data, thumbnail_size);
+			g_array_append_vals (thumbnail_array, thumbnail_data, thumbnail_size);
 		}
 	} else {
-		thumbnail_array = g_byte_array_sized_new (0);
+		thumbnail_array = g_array_sized_new (FALSE, FALSE, 1, 0);
 		if (NULL == thumbnail_array) {
 			// FIXME: I think the thumbnail prop. MUST be non-NULL;
 			//        if not, this could be cleaned up and non-fatal.
@@ -539,7 +539,7 @@ _done:
 	}
 
 	if (NULL != thumbnail_array) {
-		g_byte_array_unref (thumbnail_array);
+		g_array_unref (thumbnail_array);
 	}
 
 	return fnval;
