@@ -89,7 +89,7 @@ transition_pipeline (GstElement *pipeline, GstState state, GstClockTime timeout)
 }
 
 static void
-do_transcode (DAAPRecord *record, gchar *cachepath, gchar* target_mimetype)
+do_transcode (DmapAvRecord *record, gchar *cachepath, gchar* target_mimetype)
 {
 	gssize read_size;
 	gchar buf[BUFSIZ];
@@ -98,7 +98,7 @@ do_transcode (DAAPRecord *record, gchar *cachepath, gchar* target_mimetype)
 	GInputStream *stream = NULL;
 	GInputStream *decoded_stream = NULL;
 	
-	stream = daap_record_read (record, &error);
+	stream = dmap_av_record_read (record, &error);
 	if (NULL == stream) {
 		gchar *location = NULL;
 		g_object_get (record, "location", &location, NULL);
@@ -159,11 +159,11 @@ _return:
 	return;
 }
 
-/* NOTE: This is here and not in the individual DMAPRecords because records
+/* NOTE: This is here and not in the individual DmapRecords because records
  * have no knowledge of the database, db_dir, etc.
  */
 void
-transcode_cache (gpointer id, DAAPRecord *record, db_dir_and_target_transcode_mimetype_t *df)
+transcode_cache (guint id, DmapAvRecord *record, db_dir_and_target_transcode_mimetype_t *df)
 {
 	struct stat statbuf;
 	gboolean has_video = FALSE;
@@ -191,7 +191,7 @@ transcode_cache (gpointer id, DAAPRecord *record, db_dir_and_target_transcode_mi
 		goto _return;
 	}
 
-	format2 = dmap_mime_to_format (df->target_transcode_mimetype);
+	format2 = dmap_utils_mime_to_format (df->target_transcode_mimetype);
 	if (NULL == format2) {
 		g_warning ("Cannot transcode %s\n", df->target_transcode_mimetype);
 		goto _return;
@@ -235,21 +235,11 @@ transcode_cache (gpointer id, DAAPRecord *record, db_dir_and_target_transcode_mi
 	                       NULL);
 
 _return:
-	if (location) {
-		g_free (location);
-	}
-	if (format) {
-		g_free (format);
-	}
-	if (cacheuri) {
-		g_free (cacheuri);
-	}
-	if (cachepath) {
-		g_free (cachepath);
-	}
-	if (format2) {
-		g_free (format2);
-	}
+	g_free (location);
+	g_free (format);
+	g_free (cacheuri);
+	g_free (cachepath);
+	g_free (format2);
 
 	return;
 }
