@@ -79,25 +79,18 @@ parse_plugin_option (gchar *str, GHashTable *hash_table)
 	return plugin;
 }
 
-GByteArray *
-blob_add_atomic (GByteArray *blob, const guint8 *ptr, const size_t size)
+GArray *
+blob_add_atomic (GArray *blob, const guint8 *ptr, const size_t size)
 {
-	return g_byte_array_append (blob, ptr, size);
+	return g_array_append_vals (blob, ptr, size);
 }
 
-GByteArray *
-blob_add_string (GByteArray *blob, const gchar *str)
+GArray *
+blob_add_string (GArray *blob, const gchar *str)
 {
-	return g_byte_array_append (blob,
-				   (const guint8 *) str,
-				    strlen (str) + 1);
-}
-
-void
-slist_deep_free (GSList *list)
-{
-	g_slist_foreach (list, (GFunc)g_free, NULL);
-	g_slist_free (list);
+	return g_array_append_vals (blob,
+	                           (const guint8 *) str,
+	                            strlen (str) + 1);
 }
 
 void stringleton_init (void)
@@ -209,7 +202,7 @@ object_from_module (GType type, const gchar *module_dir, const gchar *module_nam
 		g_error ("Could not find plugin template");
 	}
 
-	/* dmapd-dmap-db-ghashtable is built in because it is used by DmapdDMAPContainerRecord: */
+	/* dmapd-dmap-db-ghashtable is built in because it is used by DmapdDmapContainerRecord: */
 	if (! strcmp (module_name, "ghashtable")) {
 		g_debug ("Not loading built in %s.", g_type_name (TYPE_DMAPD_DMAP_DB_GHASHTABLE));
 		child_type = TYPE_DMAPD_DMAP_DB_GHASHTABLE;
@@ -255,7 +248,7 @@ dmapd_util_hash_file (const gchar *uri, unsigned char hash[DMAP_HASH_SIZE])
 	GFile *file = NULL;
 	GFileInputStream *stream = NULL;
 	unsigned char buffer[BUFSIZ];
-	DMAPHashContext context;
+	DmapHashContext context;
 
 	file = g_file_new_for_uri (uri);
 	if (NULL == file) {
@@ -269,10 +262,10 @@ dmapd_util_hash_file (const gchar *uri, unsigned char hash[DMAP_HASH_SIZE])
 		goto _done;
 	}
 
-	dmap_hash_progressive_init (&context);
+	dmap_md5_progressive_init (&context);
 
 	while (0 < (bytes_read = g_input_stream_read (G_INPUT_STREAM (stream), buffer, BUFSIZ, NULL, &error))) {
-		dmap_hash_progressive_update (&context, buffer, bytes_read);
+		dmap_md5_progressive_update (&context, buffer, bytes_read);
 	}	
 
 	if (NULL != error) {
@@ -280,7 +273,7 @@ dmapd_util_hash_file (const gchar *uri, unsigned char hash[DMAP_HASH_SIZE])
 		goto _done;
 	}
 
-	dmap_hash_progressive_final (&context, hash);
+	dmap_md5_progressive_final (&context, hash);
 
 	fnval = TRUE;
 
@@ -307,7 +300,7 @@ cache_path (cache_type_t type, const gchar *db_dir, const gchar *uri)
 		goto _done;
 	}
 
-	dmap_hash_progressive_to_string (raw_hash, hash);
+	dmap_md5_progressive_to_string (raw_hash, hash);
 
 	switch (type) {
 	case CACHE_TYPE_RECORD:
@@ -329,7 +322,7 @@ _done:
 }
 
 void
-cache_store (const gchar *db_dir, const gchar *uri, GByteArray *blob)
+cache_store (const gchar *db_dir, const gchar *uri, GArray *blob)
 {
         struct stat st;
         gchar *cachepath = NULL;
